/* Generated by GOB (v2.0.20)   (do not edit directly) */

#include <glib.h>
#include <glib-object.h>


#include <gtk/gtk.h>
#include <glib/gstdio.h>
#include <libmpd/libmpd.h>
#include <unistd.h>
#include "misc.h"

#ifndef __GMPC_META_TEXT_VIEW_H__
#define __GMPC_META_TEXT_VIEW_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/*
 * Type checking and casting macros
 */
#define GMPC_TYPE_META_TEXT_VIEW	(gmpc_meta_text_view_get_type())
#define GMPC_META_TEXT_VIEW(obj)	G_TYPE_CHECK_INSTANCE_CAST((obj), gmpc_meta_text_view_get_type(), GmpcMetaTextView)
#define GMPC_META_TEXT_VIEW_CONST(obj)	G_TYPE_CHECK_INSTANCE_CAST((obj), gmpc_meta_text_view_get_type(), GmpcMetaTextView const)
#define GMPC_META_TEXT_VIEW_CLASS(klass)	G_TYPE_CHECK_CLASS_CAST((klass), gmpc_meta_text_view_get_type(), GmpcMetaTextViewClass)
#define GMPC_IS_META_TEXT_VIEW(obj)	G_TYPE_CHECK_INSTANCE_TYPE((obj), gmpc_meta_text_view_get_type ())

#define GMPC_META_TEXT_VIEW_GET_CLASS(obj)	G_TYPE_INSTANCE_GET_CLASS((obj), gmpc_meta_text_view_get_type(), GmpcMetaTextViewClass)

/* Private structure type */
typedef struct _GmpcMetaTextViewPrivate GmpcMetaTextViewPrivate;

/*
 * Main object structure
 */
#ifndef __TYPEDEF_GMPC_META_TEXT_VIEW__
#define __TYPEDEF_GMPC_META_TEXT_VIEW__
typedef struct _GmpcMetaTextView GmpcMetaTextView;
#endif
struct _GmpcMetaTextView {
	GtkTextView __parent__;
	/*< public >*/
	gboolean force_ro;
	gboolean use_monospace;
	/*< private >*/
	GmpcMetaTextViewPrivate *_priv;
};

/*
 * Class definition
 */
typedef struct _GmpcMetaTextViewClass GmpcMetaTextViewClass;
struct _GmpcMetaTextViewClass {
	GtkTextViewClass __parent__;
	/*signal*/void (* set_text_from_path) (GmpcMetaTextView * self, const gchar * path);
	/*signal*/void (* set_text_fetching) (GmpcMetaTextView * self);
	/*signal*/void (* set_text_na) (GmpcMetaTextView * self);
};


/*
 * Public methods
 */
GType	gmpc_meta_text_view_get_type	(void) G_GNUC_CONST;
GmpcMetaTextView * 	gmpc_meta_text_view_new	(int type);
void 	gmpc_meta_text_view_query_refetch	(GmpcMetaTextView * self);
void 	gmpc_meta_text_view_query_text_from_song	(GmpcMetaTextView * self,
					mpd_Song * song);
void 	gmpc_meta_text_view_set_text_from_path	(GmpcMetaTextView * self,
					const gchar * path);
void 	gmpc_meta_text_view_set_text_fetching	(GmpcMetaTextView * self);
void 	gmpc_meta_text_view_set_text_na	(GmpcMetaTextView * self);
void 	gmpc_meta_text_view_clear_entry	(GmpcMetaTextView * self);
void 	gmpc_meta_text_view_select_file	(GmpcMetaTextView * self);

/*
 * Signal connection wrapper macros
 */
#if defined(__GNUC__) && !defined(__STRICT_ANSI__)
#define gmpc_meta_text_view_connect__set_text_from_path(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_from_path",(GCallback) __extension__ ({void (* ___set_text_from_path) (GmpcMetaTextView * ___fake___self, const gchar * ___fake___path, gpointer ___data ) = (func); ___set_text_from_path; }), (data))
#define gmpc_meta_text_view_connect_after__set_text_from_path(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_from_path",(GCallback) __extension__ ({void (* ___set_text_from_path) (GmpcMetaTextView * ___fake___self, const gchar * ___fake___path, gpointer ___data ) = (func); ___set_text_from_path; }), (data))
#define gmpc_meta_text_view_connect_data__set_text_from_path(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_from_path",(GCallback) __extension__ ({void (* ___set_text_from_path) (GmpcMetaTextView * ___fake___self, const gchar * ___fake___path, gpointer ___data ) = (func); ___set_text_from_path; }), (data), (destroy_data), (GConnectFlags)(flags))
#define gmpc_meta_text_view_connect__set_text_fetching(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_fetching",(GCallback) __extension__ ({void (* ___set_text_fetching) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_fetching; }), (data))
#define gmpc_meta_text_view_connect_after__set_text_fetching(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_fetching",(GCallback) __extension__ ({void (* ___set_text_fetching) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_fetching; }), (data))
#define gmpc_meta_text_view_connect_data__set_text_fetching(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_fetching",(GCallback) __extension__ ({void (* ___set_text_fetching) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_fetching; }), (data), (destroy_data), (GConnectFlags)(flags))
#define gmpc_meta_text_view_connect__set_text_na(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_na",(GCallback) __extension__ ({void (* ___set_text_na) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_na; }), (data))
#define gmpc_meta_text_view_connect_after__set_text_na(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_na",(GCallback) __extension__ ({void (* ___set_text_na) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_na; }), (data))
#define gmpc_meta_text_view_connect_data__set_text_na(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(__extension__ ({GmpcMetaTextView *___object = (object); ___object; })),"set_text_na",(GCallback) __extension__ ({void (* ___set_text_na) (GmpcMetaTextView * ___fake___self, gpointer ___data ) = (func); ___set_text_na; }), (data), (destroy_data), (GConnectFlags)(flags))
#else /* __GNUC__ && !__STRICT_ANSI__ */
#define gmpc_meta_text_view_connect__set_text_from_path(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(object),"set_text_from_path",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_after__set_text_from_path(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(object),"set_text_from_path",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_data__set_text_from_path(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(object),"set_text_from_path",(GCallback)(func),(data),(destroy_data),(GConnectFlags)(flags))
#define gmpc_meta_text_view_connect__set_text_fetching(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(object),"set_text_fetching",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_after__set_text_fetching(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(object),"set_text_fetching",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_data__set_text_fetching(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(object),"set_text_fetching",(GCallback)(func),(data),(destroy_data),(GConnectFlags)(flags))
#define gmpc_meta_text_view_connect__set_text_na(object,func,data)	g_signal_connect(GMPC_META_TEXT_VIEW(object),"set_text_na",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_after__set_text_na(object,func,data)	g_signal_connect_after(GMPC_META_TEXT_VIEW(object),"set_text_na",(GCallback)(func),(data))
#define gmpc_meta_text_view_connect_data__set_text_na(object,func,data,destroy_data,flags)	g_signal_connect_data(GMPC_META_TEXT_VIEW(object),"set_text_na",(GCallback)(func),(data),(destroy_data),(GConnectFlags)(flags))
#endif /* __GNUC__ && !__STRICT_ANSI__ */


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
