/* Generated by GOB (v2.0.20)   (do not edit directly) */

#include <glib.h>
#include <glib-object.h>


#include <config.h>
#include <gtk/gtk.h>
#include <libmpd/libmpd.h>
#include <libmpd/libmpd-internal.h>
#include "gmpc-mpddata-model.h"
#include "gmpc-mpddata-model-private.h"

#ifndef __GMPC_MPDDATA_MODEL_SORT_H__
#define __GMPC_MPDDATA_MODEL_SORT_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/*
 * Type checking and casting macros
 */
#define GMPC_TYPE_MPDDATA_MODEL_SORT	(gmpc_mpddata_model_sort_get_type())
#define GMPC_MPDDATA_MODEL_SORT(obj)	G_TYPE_CHECK_INSTANCE_CAST((obj), gmpc_mpddata_model_sort_get_type(), GmpcMpdDataModelSort)
#define GMPC_MPDDATA_MODEL_SORT_CONST(obj)	G_TYPE_CHECK_INSTANCE_CAST((obj), gmpc_mpddata_model_sort_get_type(), GmpcMpdDataModelSort const)
#define GMPC_MPDDATA_MODEL_SORT_CLASS(klass)	G_TYPE_CHECK_CLASS_CAST((klass), gmpc_mpddata_model_sort_get_type(), GmpcMpdDataModelSortClass)
#define GMPC_IS_MPDDATA_MODEL_SORT(obj)	G_TYPE_CHECK_INSTANCE_TYPE((obj), gmpc_mpddata_model_sort_get_type ())

#define GMPC_MPDDATA_MODEL_SORT_GET_CLASS(obj)	G_TYPE_INSTANCE_GET_CLASS((obj), gmpc_mpddata_model_sort_get_type(), GmpcMpdDataModelSortClass)

/*
 * Main object structure
 */
#ifndef __TYPEDEF_GMPC_MPDDATA_MODEL_SORT__
#define __TYPEDEF_GMPC_MPDDATA_MODEL_SORT__
typedef struct _GmpcMpdDataModelSort GmpcMpdDataModelSort;
#endif
struct _GmpcMpdDataModelSort {
	GmpcMpdDataModel __parent__;
	/*< public >*/
	gchar * playlist;
};

/*
 * Class definition
 */
typedef struct _GmpcMpdDataModelSortClass GmpcMpdDataModelSortClass;
struct _GmpcMpdDataModelSortClass {
	GmpcMpdDataModelClass __parent__;
};


/*
 * Public methods
 */
GType	gmpc_mpddata_model_sort_get_type	(void) G_GNUC_CONST;
gchar * 	gmpc_mpddata_model_sort_get_playlist	(GmpcMpdDataModelSort * self);
void 	gmpc_mpddata_model_sort_set_playlist	(GmpcMpdDataModelSort * self,
					gchar * val);
GmpcMpdDataModelSort * 	gmpc_mpddata_model_sort_new	(void);

/*
 * Argument wrapping macros
 */
#if defined(__GNUC__) && !defined(__STRICT_ANSI__)
#define GMPC_MPDDATA_MODEL_SORT_PROP_PLAYLIST(arg)    	"playlist", __extension__ ({gchar *z = (arg); z;})
#define GMPC_MPDDATA_MODEL_SORT_GET_PROP_PLAYLIST(arg)	"playlist", __extension__ ({gchar **z = (arg); z;})
#else /* __GNUC__ && !__STRICT_ANSI__ */
#define GMPC_MPDDATA_MODEL_SORT_PROP_PLAYLIST(arg)    	"playlist",(gchar *)(arg)
#define GMPC_MPDDATA_MODEL_SORT_GET_PROP_PLAYLIST(arg)	"playlist",(gchar **)(arg)
#endif /* __GNUC__ && !__STRICT_ANSI__ */


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
